import pandas as pd

from io import StringIO
from pandas import DataFrame, Series

from automon import Logging


class CryptoCSV:
    def __init__(self, csv: str or open or StringIO = None,
                 dataframe: DataFrame = None,
                 delimiter: str = None, **kwargs):
        self._log = Logging(name=CryptoCSV.__name__, level=Logging.DEBUG)

        self.df = None

        if csv:
            if type(csv) is str:
                self.df = self.csv_from_string(csv, delimiter=delimiter, **kwargs)
            else:
                self.df = pd.read_csv(csv, delimiter=delimiter, **kwargs)

        if dataframe is not None:
            self.df = dataframe

    def read_csv(self, file: str, delimiter: str = None, **kwargs) -> pd.read_csv:
        self._log.info(f'imported {file}')
        return pd.read_csv(file, delimiter=delimiter, **kwargs)

    def csv_from_string(self, csv, delimiter: str = None, **kwargs) -> pd.read_csv:
        self._log.info(f'imported {csv}')
        return self.read_csv(StringIO(csv), delimiter=delimiter, **kwargs)

    def __repr__(self):
        return f'{self.df}'



import unittest
import pandas as pd

from automon.helpers.crypto import CryptoCSV


class CryptoTest(unittest.TestCase):

    def test_crypto(self):
        data = {'data': [1, 2, 3]}
        series = pd.Series(data).rename('data')
        df = pd.DataFrame(series)
        csv = df.to_csv()

        c = CryptoCSV()
        test = '''ASSET NAME	RECEIVED DATE	COST BASIS(USD)	DATE SOLD	PROCEEDS
        BTC	10/08/20	10.00	10/10/20	10.37
        BTC	10/10/20	99.00	10/12/20	100.63
        BTC	10/13/20	201.01	10/19/20	202.47'''

        self.assertTrue(CryptoCSV())
        self.assertTrue(CryptoCSV(csv=csv))
        self.assertFalse(CryptoCSV(dataframe=df).df.empty)
        self.assertEqual(type(CryptoCSV(dataframe=df).df), type(df))
        self.assertFalse(c.csv_from_string(test).empty)

        pass


if __name__ == '__main__':
    unittest.main()
